@@ -1,23 +1,40 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Handles actions related to GIS POLYGON objects
- *
- * @package PhpMyAdmin-GIS
  */
+
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Gis;
 
 use TCPDF;
+use function array_merge;
+use function array_push;
+use function array_slice;
+use function count;
+use function explode;
+use function hexdec;
+use function imagecolorallocate;
+use function imagefilledpolygon;
+use function imagestring;
+use function json_encode;
+use function max;
+use function mb_strlen;
+use function mb_strpos;
+use function mb_substr;
+use function min;
+use function pow;
+use function round;
+use function sqrt;
+use function trim;
 
 /**
  * Handles actions related to GIS POLYGON objects
- *
- * @package PhpMyAdmin-GIS
  */
 class GisPolygon extends GisGeometry
 {
-    // Hold the singleton instance of the class
-    private static $_instance;
+    /** @var self */
+    private static $instance;
 
     /**
      * A private constructor; prevents direct creation of object.
@@ -32,16 +49,16 @@ class GisPolygon extends GisGeometry
      * Returns the singleton.
      *
      * @return GisPolygon the singleton
+     *
      * @access public
      */
     public static function singleton()
     {
-        if (!isset(self::$_instance)) {
-            $class = __CLASS__;
-            self::$_instance = new $class;
+        if (! isset(self::$instance)) {
+            self::$instance = new GisPolygon();
         }
 
-        return self::$_instance;
+        return self::$instance;
     }
 
     /**
@@ -50,6 +67,7 @@ class GisPolygon extends GisGeometry
      * @param string $spatial spatial data of a row
      *
      * @return array an array containing the min, max values for x and y coordinates
+     *
      * @access public
      */
     public function scaleRow($spatial)
@@ -62,32 +80,33 @@ class GisPolygon extends GisGeometry
         );
 
         // If the polygon doesn't have an inner ring, use polygon itself
-        if (mb_strpos($polygon, "),(") === false) {
+        if (mb_strpos($polygon, '),(') === false) {
             $ring = $polygon;
         } else {
             // Separate outer ring and use it to determine min-max
-            $parts = explode("),(", $polygon);
+            $parts = explode('),(', $polygon);
             $ring = $parts[0];
         }
 
-        return $this->setMinMax($ring, array());
+        return $this->setMinMax($ring, []);
     }
 
     /**
      * Adds to the PNG image object, the data related to a row in the GIS dataset.
      *
-     * @param string $spatial    GIS POLYGON object
-     * @param string $label      Label for the GIS POLYGON object
-     * @param string $fill_color Color for the GIS POLYGON object
-     * @param array  $scale_data Array containing data related to scaling
-     * @param object $image      Image object
+     * @param string      $spatial    GIS POLYGON object
+     * @param string|null $label      Label for the GIS POLYGON object
+     * @param string      $fill_color Color for the GIS POLYGON object
+     * @param array       $scale_data Array containing data related to scaling
+     * @param resource    $image      Image object
+     *
+     * @return resource the modified image object
      *
-     * @return object the modified image object
      * @access public
      */
     public function prepareRowAsPng(
         $spatial,
-        $label,
+        ?string $label,
         $fill_color,
         array $scale_data,
         $image
@@ -103,16 +122,15 @@ class GisPolygon extends GisGeometry
         $polygon = mb_substr(
             $spatial,
             9,
-
             mb_strlen($spatial) - 11
         );
 
         // If the polygon doesn't have an inner polygon
-        if (mb_strpos($polygon, "),(") === false) {
+        if (mb_strpos($polygon, '),(') === false) {
             $points_arr = $this->extractPoints($polygon, $scale_data, true);
         } else {
             // Separate outer and inner polygons
-            $parts = explode("),(", $polygon);
+            $parts = explode('),(', $polygon);
             $outer = $parts[0];
             $inner = array_slice($parts, 1);
 
@@ -127,14 +145,14 @@ class GisPolygon extends GisGeometry
         }
 
         // draw polygon
-        imagefilledpolygon($image, $points_arr, sizeof($points_arr) / 2, $color);
+        @imagefilledpolygon($image, $points_arr, count($points_arr) / 2, $color);
         // print label if applicable
         if (isset($label) && trim($label) != '') {
             imagestring(
                 $image,
                 1,
-                $points_arr[2],
-                $points_arr[3],
+                (int) round($points_arr[2]),
+                (int) round($points_arr[3]),
                 trim($label),
                 $black
             );
@@ -146,22 +164,27 @@ class GisPolygon extends GisGeometry
     /**
      * Adds to the TCPDF instance, the data related to a row in the GIS dataset.
      *
-     * @param string $spatial    GIS POLYGON object
-     * @param string $label      Label for the GIS POLYGON object
-     * @param string $fill_color Color for the GIS POLYGON object
-     * @param array  $scale_data Array containing data related to scaling
-     * @param TCPDF  $pdf        TCPDF instance
+     * @param string      $spatial    GIS POLYGON object
+     * @param string|null $label      Label for the GIS POLYGON object
+     * @param string      $fill_color Color for the GIS POLYGON object
+     * @param array       $scale_data Array containing data related to scaling
+     * @param TCPDF       $pdf        TCPDF instance
      *
      * @return TCPDF the modified TCPDF instance
+     *
      * @access public
      */
-    public function prepareRowAsPdf($spatial, $label, $fill_color, array $scale_data, $pdf)
+    public function prepareRowAsPdf($spatial, ?string $label, $fill_color, array $scale_data, $pdf)
     {
         // allocate colors
         $red = hexdec(mb_substr($fill_color, 1, 2));
         $green = hexdec(mb_substr($fill_color, 3, 2));
         $blue = hexdec(mb_substr($fill_color, 4, 2));
-        $color = array($red, $green, $blue);
+        $color = [
+            $red,
+            $green,
+            $blue,
+        ];
 
         // Trim to remove leading 'POLYGON((' and trailing '))'
         $polygon = mb_substr(
@@ -171,11 +194,11 @@ class GisPolygon extends GisGeometry
         );
 
         // If the polygon doesn't have an inner polygon
-        if (mb_strpos($polygon, "),(") === false) {
+        if (mb_strpos($polygon, '),(') === false) {
             $points_arr = $this->extractPoints($polygon, $scale_data, true);
         } else {
             // Separate outer and inner polygons
-            $parts = explode("),(", $polygon);
+            $parts = explode('),(', $polygon);
             $outer = $parts[0];
             $inner = array_slice($parts, 1);
 
@@ -190,7 +213,7 @@ class GisPolygon extends GisGeometry
         }
 
         // draw polygon
-        $pdf->Polygon($points_arr, 'F*', array(), $color, true);
+        $pdf->Polygon($points_arr, 'F*', [], $color, true);
         // print label if applicable
         if (isset($label) && trim($label) != '') {
             $pdf->SetXY($points_arr[2], $points_arr[3]);
@@ -210,20 +233,21 @@ class GisPolygon extends GisGeometry
      * @param array  $scale_data Array containing data related to scaling
      *
      * @return string the code related to a row in the GIS dataset
+     *
      * @access public
      */
     public function prepareRowAsSvg($spatial, $label, $fill_color, array $scale_data)
     {
-        $polygon_options = array(
+        $polygon_options = [
             'name'         => $label,
-            'id'           => $label . rand(),
+            'id'           => $label . $this->getRandomId(),
             'class'        => 'polygon vector',
             'stroke'       => 'black',
             'stroke-width' => 0.5,
             'fill'         => $fill_color,
             'fill-rule'    => 'evenodd',
             'fill-opacity' => 0.8,
-        );
+        ];
 
         // Trim to remove leading 'POLYGON((' and trailing '))'
         $polygon
@@ -236,24 +260,24 @@ class GisPolygon extends GisGeometry
         $row = '<path d="';
 
         // If the polygon doesn't have an inner polygon
-        if (mb_strpos($polygon, "),(") === false) {
-            $row .= $this->_drawPath($polygon, $scale_data);
+        if (mb_strpos($polygon, '),(') === false) {
+            $row .= $this->drawPath($polygon, $scale_data);
         } else {
             // Separate outer and inner polygons
-            $parts = explode("),(", $polygon);
+            $parts = explode('),(', $polygon);
             $outer = $parts[0];
             $inner = array_slice($parts, 1);
 
-            $row .= $this->_drawPath($outer, $scale_data);
+            $row .= $this->drawPath($outer, $scale_data);
 
             foreach ($inner as $inner_poly) {
-                $row .= $this->_drawPath($inner_poly, $scale_data);
+                $row .= $this->drawPath($inner_poly, $scale_data);
             }
         }
 
         $row .= '"';
         foreach ($polygon_options as $option => $val) {
-            $row .= ' ' . $option . '="' . trim($val) . '"';
+            $row .= ' ' . $option . '="' . trim((string) $val) . '"';
         }
         $row .= '/>';
 
@@ -267,26 +291,35 @@ class GisPolygon extends GisGeometry
      * @param string $spatial    GIS POLYGON object
      * @param int    $srid       Spatial reference ID
      * @param string $label      Label for the GIS POLYGON object
-     * @param string $fill_color Color for the GIS POLYGON object
+     * @param array  $fill_color Color for the GIS POLYGON object
      * @param array  $scale_data Array containing data related to scaling
      *
      * @return string JavaScript related to a row in the GIS dataset
+     *
      * @access public
      */
     public function prepareRowAsOl($spatial, $srid, $label, $fill_color, array $scale_data)
     {
-        $style_options = array(
-            'strokeColor' => '#000000',
-            'strokeWidth' => 0.5,
-            'fillColor'   => $fill_color,
-            'fillOpacity' => 0.8,
-            'label'       => $label,
-            'fontSize'    => 10,
-        );
+        $fill_opacity = 0.8;
+        array_push($fill_color, $fill_opacity);
+        $fill_style = ['color' => $fill_color];
+        $stroke_style = [
+            'color' => [0,0,0],
+            'width' => 0.5,
+        ];
+        $row =  'var style = new ol.style.Style({'
+            . 'fill: new ol.style.Fill(' . json_encode($fill_style) . '),'
+            . 'stroke: new ol.style.Stroke(' . json_encode($stroke_style) . ')';
+        if (trim($label) !== '') {
+            $text_style = ['text' => trim($label)];
+            $row .= ',text: new ol.style.Text(' . json_encode($text_style) . ')';
+        }
+        $row .= '});';
+
         if ($srid == 0) {
             $srid = 4326;
         }
-        $row = $this->getBoundsForOl($srid, $scale_data);
+        $row .= $this->getBoundsForOl($srid, $scale_data);
 
         // Trim to remove leading 'POLYGON((' and trailing '))'
         $polygon
@@ -294,17 +327,16 @@ class GisPolygon extends GisGeometry
             mb_substr(
                 $spatial,
                 9,
-
                 mb_strlen($spatial) - 11
             );
 
         // Separate outer and inner polygons
-        $parts = explode("),(", $polygon);
-        $row .= 'vectorLayer.addFeatures(new OpenLayers.Feature.Vector('
-            . $this->getPolygonForOpenLayers($parts, $srid)
-            . ', null, ' . json_encode($style_options) . '));';
+        $parts = explode('),(', $polygon);
 
-        return $row;
+        return $row . $this->getPolygonForOpenLayers($parts, $srid)
+            . 'var feature = new ol.Feature({geometry: polygon});'
+            . 'feature.setStyle(style);'
+            . 'vectorLayer.addFeature(feature);';
     }
 
     /**
@@ -314,9 +346,10 @@ class GisPolygon extends GisGeometry
      * @param array  $scale_data Array containing data related to scaling
      *
      * @return string the code to draw the ring
+     *
      * @access private
      */
-    private function _drawPath($polygon, array $scale_data)
+    private function drawPath($polygon, array $scale_data)
     {
         $points_arr = $this->extractPoints($polygon, $scale_data);
 
@@ -338,30 +371,29 @@ class GisPolygon extends GisGeometry
      * @param string $empty    Value for empty points
      *
      * @return string WKT with the set of parameters passed by the GIS editor
+     *
      * @access public
      */
     public function generateWkt(array $gis_data, $index, $empty = '')
     {
-        $no_of_lines = isset($gis_data[$index]['POLYGON']['no_of_lines'])
-            ? $gis_data[$index]['POLYGON']['no_of_lines'] : 1;
+        $no_of_lines = $gis_data[$index]['POLYGON']['no_of_lines'] ?? 1;
         if ($no_of_lines < 1) {
             $no_of_lines = 1;
         }
 
         $wkt = 'POLYGON(';
         for ($i = 0; $i < $no_of_lines; $i++) {
-            $no_of_points = isset($gis_data[$index]['POLYGON'][$i]['no_of_points'])
-                ? $gis_data[$index]['POLYGON'][$i]['no_of_points'] : 4;
+            $no_of_points = $gis_data[$index]['POLYGON'][$i]['no_of_points'] ?? 4;
             if ($no_of_points < 4) {
                 $no_of_points = 4;
             }
             $wkt .= '(';
             for ($j = 0; $j < $no_of_points; $j++) {
-                $wkt .= ((isset($gis_data[$index]['POLYGON'][$i][$j]['x'])
-                        && trim($gis_data[$index]['POLYGON'][$i][$j]['x']) != '')
+                $wkt .= (isset($gis_data[$index]['POLYGON'][$i][$j]['x'])
+                        && trim((string) $gis_data[$index]['POLYGON'][$i][$j]['x']) != ''
                         ? $gis_data[$index]['POLYGON'][$i][$j]['x'] : $empty)
-                    . ' ' . ((isset($gis_data[$index]['POLYGON'][$i][$j]['y'])
-                        && trim($gis_data[$index]['POLYGON'][$i][$j]['y']) != '')
+                    . ' ' . (isset($gis_data[$index]['POLYGON'][$i][$j]['y'])
+                        && trim((string) $gis_data[$index]['POLYGON'][$i][$j]['y']) != ''
                         ? $gis_data[$index]['POLYGON'][$i][$j]['y'] : $empty) . ',';
             }
             $wkt
@@ -380,9 +412,8 @@ class GisPolygon extends GisGeometry
                 0,
                 mb_strlen($wkt) - 1
             );
-        $wkt .= ')';
 
-        return $wkt;
+        return $wkt . ')';
     }
 
     /**
@@ -391,12 +422,12 @@ class GisPolygon extends GisGeometry
      * @param array $ring array of points forming the ring
      *
      * @return float the area of a closed simple polygon
+     *
      * @access public
      * @static
      */
     public static function area(array $ring)
     {
-
         $no_of_points = count($ring);
 
         // If the last point is same as the first point ignore it
@@ -429,6 +460,7 @@ class GisPolygon extends GisGeometry
      * @param array $ring array of points forming the ring
      *
      * @return bool whether a set of points represents an outer ring
+     *
      * @access public
      * @static
      */
@@ -436,7 +468,7 @@ class GisPolygon extends GisGeometry
     {
         // If area is negative then it's in clockwise orientation,
         // i.e. it's an outer ring
-        return GisPolygon::area($ring) < 0;
+        return self::area($ring) < 0;
     }
 
     /**
@@ -446,6 +478,7 @@ class GisPolygon extends GisGeometry
      * @param array $polygon array of points forming the ring
      *
      * @return bool whether a given point is inside a given polygon
+     *
      * @access public
      * @static
      */
@@ -466,17 +499,17 @@ class GisPolygon extends GisGeometry
         $p1 = $polygon[0];
         for ($i = 1; $i <= $no_of_points; $i++) {
             $p2 = $polygon[$i % $no_of_points];
-            if ($point['y'] <= min(array($p1['y'], $p2['y']))) {
+            if ($point['y'] <= min([$p1['y'], $p2['y']])) {
                 $p1 = $p2;
                 continue;
             }
 
-            if ($point['y'] > max(array($p1['y'], $p2['y']))) {
+            if ($point['y'] > max([$p1['y'], $p2['y']])) {
                 $p1 = $p2;
                 continue;
             }
 
-            if ($point['x'] > max(array($p1['x'], $p2['x']))) {
+            if ($point['x'] > max([$p1['x'], $p2['x']])) {
                 $p1 = $p2;
                 continue;
             }
@@ -502,12 +535,17 @@ class GisPolygon extends GisGeometry
      *
      * @param array $ring array of points forming the ring
      *
-     * @return array|void a point on the surface of the ring
+     * @return array|false a point on the surface of the ring
+     *
      * @access public
      * @static
      */
     public static function getPointOnSurface(array $ring)
     {
+        $x0 = null;
+        $x1 = null;
+        $y0 = null;
+        $y1 = null;
         // Find two consecutive distinct points.
         for ($i = 0, $nb = count($ring) - 1; $i < $nb; $i++) {
             if ($ring[$i]['y'] != $ring[$i + 1]['y']) {
@@ -519,7 +557,7 @@ class GisPolygon extends GisGeometry
             }
         }
 
-        if (!isset($x0)) {
+        if (! isset($x0)) {
             return false;
         }
 
@@ -529,9 +567,9 @@ class GisPolygon extends GisGeometry
 
         // Always keep $epsilon < 1 to go with the reduction logic down here
         $epsilon = 0.1;
-        $denominator = sqrt(pow(($y1 - $y0), 2) + pow(($x0 - $x1), 2));
-        $pointA = array();
-        $pointB = array();
+        $denominator = sqrt(pow($y1 - $y0, 2) + pow($x0 - $x1, 2));
+        $pointA = [];
+        $pointB = [];
 
         while (true) {
             // Get the points on either sides of the line
@@ -544,11 +582,11 @@ class GisPolygon extends GisGeometry
 
             // One of the points should be inside the polygon,
             // unless epsilon chosen is too large
-            if (GisPolygon::isPointInsidePolygon($pointA, $ring)) {
+            if (self::isPointInsidePolygon($pointA, $ring)) {
                 return $pointA;
             }
 
-            if (GisPolygon::isPointInsidePolygon($pointB, $ring)) {
+            if (self::isPointInsidePolygon($pointB, $ring)) {
                 return $pointB;
             }
 
@@ -567,11 +605,12 @@ class GisPolygon extends GisGeometry
      * @param int    $index Index of the geometry
      *
      * @return array params for the GIS data editor from the value of the GIS column
+     *
      * @access public
      */
     public function generateParams($value, $index = -1)
     {
-        $params = array();
+        $params = [];
         if ($index == -1) {
             $index = 0;
             $data = GisGeometry::generateParams($value);
@@ -591,7 +630,7 @@ class GisPolygon extends GisGeometry
                 mb_strlen($wkt) - 11
             );
         // Separate each linestring
-        $linerings = explode("),(", $polygon);
+        $linerings = explode('),(', $polygon);
         $params[$index]['POLYGON']['no_of_lines'] = count($linerings);
 
         $j = 0;
