@@ -1,16 +1,14 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
 /**
  * Properties class for the schema export plug-in
- *
- * @package PhpMyAdmin
  */
+
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Properties\Plugins;
 
 /**
  * Defines possible options and getters and setters for them.
- *
- * @package PhpMyAdmin
  */
 class SchemaPluginProperties extends PluginPropertyItem
 {
@@ -29,7 +27,7 @@ class SchemaPluginProperties extends PluginPropertyItem
      */
     public function getItemType()
     {
-        return "schema";
+        return 'schema';
     }
 
     /**
