@@ -1,20 +1,12 @@
 <?php
-/* vim: set expandtab sw=4 ts=4 sts=4: */
-/**
- * hold PhpMyAdmin\Twig\PluginsExtension class
- *
- * @package PhpMyAdmin\Twig
- */
+
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Twig;
 
 use Twig\Extension\AbstractExtension;
 use Twig\TwigFunction;
 
-/**
- * Class PluginsExtension
- *
- * @package PhpMyAdmin\Twig
- */
 class PluginsExtension extends AbstractExtension
 {
     /**
@@ -24,27 +16,27 @@ class PluginsExtension extends AbstractExtension
      */
     public function getFunctions()
     {
-        return array(
+        return [
             new TwigFunction(
-                'Plugins_checkboxCheck',
+                'checkbox_check',
                 'PhpMyAdmin\Plugins::checkboxCheck',
-                array('is_safe' => array('html'))
+                ['is_safe' => ['html']]
             ),
             new TwigFunction(
-                'Plugins_getChoice',
+                'get_choice',
                 'PhpMyAdmin\Plugins::getChoice',
-                array('is_safe' => array('html'))
+                ['is_safe' => ['html']]
             ),
             new TwigFunction(
-                'Plugins_getDefault',
+                'get_default_plugin',
                 'PhpMyAdmin\Plugins::getDefault',
-                array('is_safe' => array('html'))
+                ['is_safe' => ['html']]
             ),
             new TwigFunction(
-                'Plugins_getOptions',
+                'get_options',
                 'PhpMyAdmin\Plugins::getOptions',
-                array('is_safe' => array('html'))
+                ['is_safe' => ['html']]
             ),
-        );
+        ];
     }
 }
